@@ -59,7 +59,7 @@ static void printer_list_window_class_init (PrinterListWindowClass * klass);
 static void printer_list_window_init (PrinterListWindow * obj);
 
 static void load_printer_list_in_treeview (PrinterListWindow * win);
-static void icon_theme_changed_cb (XfceIconTheme * icon_theme, PrinterListWindow * win);
+static void icon_theme_changed_cb (GtkIconTheme * icon_theme, PrinterListWindow * win);
 
 static void tree_view_row_activated_cb (GtkWidget * widget, GtkTreePath * path, GtkTreeViewColumn * col,
                                         PrinterListWindow * win);
@@ -398,7 +398,7 @@ icon_theme_update_foreach_func (GtkTreeModel * model, GtkTreePath * path, GtkTre
 /* Callbacks */
 
 static void
-icon_theme_changed_cb (XfceIconTheme * icon_theme, PrinterListWindow * win)
+icon_theme_changed_cb (GtkIconTheme * icon_theme, PrinterListWindow * win)
 {
   GtkTreeModel *model;
   PrinterListWindowPrivate *priv = PRINTER_LIST_WINDOW_GET_PRIVATE (win);
